'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vueFunctionApi = require('vue-function-api');

var version = "0.1.1";

/**
 * helper function to use vuex getters
 * @param context
 * @param getters Name array of getters.
 */
var useGetters = function (context, getters) {
    var computedObject = {};
    getters.forEach(function (key) {
        computedObject[key] = vueFunctionApi.computed(function () { return context.store.getters[key]; });
    });
    return computedObject;
};

var DEFAULT_EXTRA_KEYS = ['router', 'route'];
var plugin = {
    install: function (Vue, options) {
        if (options === void 0) { options = {}; }
        var pureVueProtoKeys = Object.keys(Vue.prototype);
        var pureVm = Object.keys(new Vue());
        var extraKeys = (options.extraKeys || []).concat(DEFAULT_EXTRA_KEYS);
        function wrapperSetup() {
            var vm = this;
            var $options = vm.$options;
            var setup = $options.setup;
            if (!setup) {
                return;
            }
            if (typeof setup !== 'function') {
                // eslint-disable-next-line no-console
                console.warn('The "setup" option should be a function that returns a object in component definitions.', vm);
                return;
            }
            // wapper the setup option, so that we can use prototype properties and mixin properties in context
            $options.setup = function wrappedSetup(props, ctx) {
                // to extend context
                Object.keys(vm)
                    .filter(function (x) { return /^\$/.test(x) && pureVm.indexOf(x) === -1; })
                    .forEach(function (x) {
                    // @ts-ignore
                    ctx[x.replace(/^\$/, '')] = vm[x];
                });
                Object.keys(vm.$root.constructor.prototype)
                    .filter(function (x) { return /^\$/.test(x) && pureVueProtoKeys.indexOf(x) === -1; })
                    .forEach(function (x) {
                    // @ts-ignore
                    ctx[x.replace(/^\$/, '')] = vm[x];
                });
                // to extend context with router properties
                extraKeys.forEach(function (key) {
                    // @ts-ignore
                    var value = vm['$' + key];
                    if (value) {
                        ctx[key] = value;
                    }
                });
                // @ts-ignore
                return setup(props, ctx);
            };
        }
        Vue.mixin({
            beforeCreate: wrapperSetup,
        });
    },
};

exports.plugin = plugin;
exports.useGetters = useGetters;
exports.version = version;
